bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.random
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.random